@@ -4,7 +4,7 @@
  *	http://home.gna.org/subtitleeditor/
  *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2009, kitone
+ *	Copyright @ 2005-2012, kitone
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -106,6 +106,22 @@ public:
 					Gtk::Stock::MEDIA_REWIND,
 					_("Skip _Backwards")));
 
+		action_group->add(
+				Gtk::Action::create(
+					"video-player/skip-backwards-frame", 
+					Gtk::Stock::MEDIA_REWIND,
+					_("Frame"), 
+					_("Frame skip backwards")),
+					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_backwards), FRAME));
+
+		action_group->add(
+				Gtk::Action::create(
+					"video-player/skip-backwards-tiny", 
+					Gtk::Stock::MEDIA_REWIND,
+					_("Tiny"), 
+					_("Tiny skip backwards")),
+					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_backwards), TINY));
+
 		action_group->add(
 				Gtk::Action::create(
 					"video-player/skip-backwards-very-short", 
@@ -145,6 +161,22 @@ public:
 					Gtk::Stock::MEDIA_FORWARD,
 					_("Skip _Forward")));
 
+		action_group->add(
+				Gtk::Action::create(
+					"video-player/skip-forward-frame", 
+					Gtk::Stock::MEDIA_FORWARD,
+					_("Frame"), 
+					_("Frame skip forward")), 
+					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_forward), FRAME));
+
+		action_group->add(
+				Gtk::Action::create(
+					"video-player/skip-forward-tiny", 
+					Gtk::Stock::MEDIA_FORWARD,
+					_("Tiny"), 
+					_("Tiny skip forward")), 
+					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_forward), TINY));
+
 		action_group->add(
 				Gtk::Action::create(
 					"video-player/skip-forward-very-short", 
@@ -294,6 +326,23 @@ public:
 					_("Audio Track"),
 					_("Choice of an audio track")));
 
+		// Recent files
+		Glib::RefPtr<Gtk::RecentAction> recentAction = Gtk::RecentAction::create("video-player/recent-files", _("_Recent Files"));
+
+		Gtk::RecentFilter filter;
+		filter.set_name("subtitleeditor");
+		filter.add_group("subtitleeditor-video-player");
+		recentAction->set_filter(filter);
+		recentAction->set_show_icons(false);
+		recentAction->set_show_numbers(true);
+		recentAction->set_show_tips(true);
+		//recentAction->set_show_not_found(false);
+		recentAction->set_sort_type(Gtk::RECENT_SORT_MRU);
+
+		recentAction->signal_item_activated().connect(
+				sigc::mem_fun(*this, &VideoPlayerManagement::on_recent_item_activated));
+		action_group->add(recentAction);
+
 		// ui
 		Glib::RefPtr<Gtk::UIManager> ui = get_ui_manager();
 
@@ -305,6 +354,7 @@ public:
 			"		<menu name='menu-video' action='menu-video'>"
 			"			<placeholder name='video-player-management'>"
 			"					<menuitem action='video-player/open'/>"
+			"					<menuitem action='video-player/recent-files'/>"
 			"					<menuitem action='video-player/close'/>"
 			"					<separator/>"
 			"					<menu action='menu-audio-track'>"
@@ -316,12 +366,16 @@ public:
 			"					<menuitem action='video-player/play-pause'/>"
 			"					<separator/>"
 			"					<menu action='video-player/menu-skip-forward'>"
+			"						<menuitem action='video-player/skip-forward-frame'/>"
+			"						<menuitem action='video-player/skip-forward-tiny'/>"
 			"						<menuitem action='video-player/skip-forward-very-short'/>"
 			"						<menuitem action='video-player/skip-forward-short'/>"
 			"						<menuitem action='video-player/skip-forward-medium'/>"
 			"						<menuitem action='video-player/skip-forward-long'/>"
 			"					</menu>"
 			"					<menu action='video-player/menu-skip-backwards'>"
+			"						<menuitem action='video-player/skip-backwards-frame'/>"
+			"						<menuitem action='video-player/skip-backwards-tiny'/>"
 			"						<menuitem action='video-player/skip-backwards-very-short'/>"
 			"						<menuitem action='video-player/skip-backwards-short'/>"
 			"						<menuitem action='video-player/skip-backwards-medium'/>"
@@ -400,11 +454,15 @@ public:
 		SET_SENSITIVE("video-player/rate-faster", has_media);
 		SET_SENSITIVE("video-player/rate-normal", has_media);
 
+		SET_SENSITIVE("video-player/skip-forward-frame", has_media);
+		SET_SENSITIVE("video-player/skip-forward-tiny", has_media);
 		SET_SENSITIVE("video-player/skip-forward-very-short", has_media);
 		SET_SENSITIVE("video-player/skip-forward-short", has_media);
 		SET_SENSITIVE("video-player/skip-forward-medium", has_media);
 		SET_SENSITIVE("video-player/skip-forward-long", has_media);
 
+		SET_SENSITIVE("video-player/skip-backwards-frame", has_media);
+		SET_SENSITIVE("video-player/skip-backwards-tiny", has_media);
 		SET_SENSITIVE("video-player/skip-backwards-very-short", has_media);
 		SET_SENSITIVE("video-player/skip-backwards-short", has_media);
 		SET_SENSITIVE("video-player/skip-backwards-medium", has_media);
@@ -642,6 +700,8 @@ protected:
 			Glib::ustring uri = ui.get_uri();
 
 			player()->open(uri);
+
+			add_in_recent_manager(uri);
 		}
 	}
 
@@ -691,35 +751,45 @@ protected:
 	 */
 	enum SkipType
 	{
+		FRAME,
+		TINY,
 		VERY_SHORT,
 		SHORT,
 		MEDIUM,
 		LONG
 	};
 
+	/*
+	 */
+	long get_skip_as_msec(SkipType skip)
+	{
+		if(skip == FRAME)
+		{
+			int numerator = 0, denominator = 0;
+			if(player()->get_framerate(&numerator, &denominator) > 0)
+				return denominator * 1000 / numerator;
+		}
+		else if(skip == TINY)
+			return get_config().get_value_int("video-player", "skip-tiny");
+		else if(skip == VERY_SHORT)
+			return get_config().get_value_int("video-player", "skip-very-short") * 1000;
+		else if(skip == SHORT)
+			return get_config().get_value_int("video-player", "skip-short") * 1000;
+		else if(skip == MEDIUM)
+			return get_config().get_value_int("video-player", "skip-medium") * 1000;
+		else if(skip == LONG)
+			return get_config().get_value_int("video-player", "skip-long") * 1000;
+		return 0;
+	}
+
 	/*
 	 * Make a skip backwards depending on the type.
 	 */
 	void on_skip_backwards(SkipType skip)
 	{
-		int value = 0;
+		long newpos = player()->get_position() - get_skip_as_msec(skip);
 
-		Glib::ustring key;
-
-		if(skip == VERY_SHORT)
-			key = "skip-very-short";
-		else if(skip == SHORT)
-			key = "skip-short";
-		else if(skip == MEDIUM)
-			key = "skip-medium";
-		else if(skip == LONG)
-			key = "skip-long";
-
-		value = get_config().get_value_int("video-player", key);
-
-		long newpos = player()->get_position() - SubtitleTime(0, 0, value, 0).totalmsecs;
-
-		player()->seek(newpos); // FIXME faster = true
+		player()->seek(newpos);
 	}
 
 	/*
@@ -727,24 +797,9 @@ protected:
 	 */
 	void on_skip_forward(SkipType skip)
 	{
-		int value = 0;
+		long newpos = player()->get_position() + get_skip_as_msec(skip);
 
-		Glib::ustring key;
-
-		if(skip == VERY_SHORT)
-			key = "skip-very-short";
-		else if(skip == SHORT)
-			key = "skip-short";
-		else if(skip == MEDIUM)
-			key = "skip-medium";
-		else if(skip == LONG)
-			key = "skip-long";
-
-		value = get_config().get_value_int("video-player", key);
-
-		long newpos = player()->get_position() + SubtitleTime(0, 0, value, 0).totalmsecs;
-
-		player()->seek(newpos); // FIXME faster = true
+		player()->seek(newpos);
 	}
 
 	/*
@@ -925,6 +980,41 @@ protected:
 		}
 	}
 
+	/*
+	 */
+	void add_in_recent_manager(const Glib::ustring &uri)
+	{
+		se_debug_message(SE_DEBUG_PLUGINS, "uri=%s", uri.c_str());
+
+		Gtk::RecentManager::Data data;
+		//data.mime_type = "subtitle/";
+		data.app_name = Glib::get_application_name();
+		data.app_exec = Glib::get_prgname();
+		data.groups.push_back("subtitleeditor-video-player");
+		data.is_private = false;
+		Gtk::RecentManager::get_default()->add_item(uri, data);
+	}
+
+	/*
+	 * Open a recent video
+	 */
+	void on_recent_item_activated()
+	{
+		se_debug(SE_DEBUG_PLUGINS);
+
+		Glib::RefPtr<Gtk::Action> action = action_group->get_action("video-player/recent-files");
+
+		Glib::RefPtr<Gtk::RecentAction> recentAction = Glib::RefPtr<Gtk::RecentAction>::cast_static(action);
+
+		Glib::RefPtr<Gtk::RecentInfo> cur = recentAction->get_current_item();
+		if(cur)
+		{
+			se_debug_message(SE_DEBUG_PLUGINS, "uri=%s", cur->get_uri().c_str());
+
+			player()->open(cur->get_uri());
+		}
+	}
+
 protected:
 	Gtk::UIManager::ui_merge_id ui_id;
 	Gtk::UIManager::ui_merge_id ui_id_audio;
