@@ -36,16 +36,16 @@
 /*
  *
  */
-Application::Application(BaseObjectType *cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)//int argc, char *argv[])
+Application::Application(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder>& builder)//int argc, char *argv[])
 :Gtk::Window(cobject)
 {
-	refGlade->get_widget_derived("statusbar", m_statusbar);
+	builder->get_widget_derived("statusbar", m_statusbar);
 
-	refGlade->get_widget("vbox-main", m_vboxMain);
-	refGlade->get_widget("paned-multimedia", m_paned_multimedia);
-	refGlade->get_widget_derived("video-player", m_video_player);
-	refGlade->get_widget_derived("waveform-editor", m_waveform_editor);
-	refGlade->get_widget("notebook-documents", m_notebook_documents);
+	builder->get_widget("vbox-main", m_vboxMain);
+	builder->get_widget("paned-multimedia", m_paned_multimedia);
+	builder->get_widget_derived("video-player", m_video_player);
+	builder->get_widget_derived("waveform-editor", m_waveform_editor);
+	builder->get_widget("notebook-documents", m_notebook_documents);
 
 	init_panel_multimedia();
 
@@ -345,6 +345,27 @@ void Application::on_document_delete(Document *doc)
  */
 void Application::on_current_document_changed(Document* doc)
 {
+	// Update page
+	// First check if it's not already the good page
+	int cur_id = m_notebook_documents->get_current_page();
+	Gtk::Widget *cur_w = m_notebook_documents->get_nth_page(cur_id);
+
+	Document* cur_doc = static_cast<Document*>(cur_w->get_data("document"));
+	if(cur_doc != doc)
+	{
+		// This is not the good page, active it
+		for( int i = 0; i < m_notebook_documents->get_n_pages(); ++i)
+		{
+			Gtk::Widget *w = m_notebook_documents->get_nth_page(i);
+			Document *document = static_cast<Document*>(w->get_data("document"));
+			if(document == doc)
+			{
+				m_notebook_documents->set_current_page(i);
+				break;
+			}
+		}
+	}
+	// Update actions
 	std::list<ExtensionInfo*> actions = ExtensionManager::instance().get_info_list_from_categorie("action");
 
 	for(std::list<ExtensionInfo*>::iterator it = actions.begin(); it != actions.end(); ++it)
