@@ -320,7 +320,17 @@ public:
 		else if(value < mincps)
 			property_foreground() = "blue";
 		else
-			property_foreground() = "black";
+		{
+			if(flags & Gtk::CELL_RENDERER_SELECTED)
+				property_foreground() = "white";
+			else
+				property_foreground() = "black";
+		}
+
+		// Remove the flag to avoid conflict with selected color
+		// FIXME do this with a better way...
+		if(flags & Gtk::CELL_RENDERER_SELECTED)
+			flags &= ~Gtk::CELL_RENDERER_SELECTED;
 
 		Gtk::CellRendererText::render_vfunc(window, widget, bg_area, cell_area, expose_area, flags);
 	}
@@ -1250,7 +1260,12 @@ void SubtitleView::select_and_set_cursor(const Gtk::TreeIter &iter, bool start_e
 		column = m_columns["text"];
 
 	get_selection()->select(iter);
-	set_cursor(m_subtitleModel->get_path(iter), *column, start_editing);
+
+	const Gtk::TreeModel::Path path_from_iter = m_subtitleModel->get_path(iter);
+	// Select the row and the column (cell)
+	set_cursor(path_from_iter, *column, start_editing);
+	// Scroll to center the current selection in the view
+	scroll_to_row(path_from_iter, 0.5);
 }
 
 
